package
Version:
v0.0.0-...-4468414
Opens a new window with list of versions in this module.
Published: Feb 4, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ClientReq struct {
ClientId *int64 `uri:"clientId" binding:"required"`
}
type JobReq struct {
JobId int64 `header:"jobId" binding:"required"`
}
type UserReq struct {
ClientId *int64 `uri:"clientId" binding:"required"`
UserId *int64 `uri:"userId" binding:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.